<?php

/**
 * @author: VLThemes
 * @version: 2.0.0
 */

/**
 * Demo import
 */
if ( ! function_exists( 'leedo_demo_import_files' ) ) {
	function leedo_demo_import_files() {
		return array(
			array(
				'import_file_name' => esc_html__( 'Demo Import', 'leedo' ),
				'local_import_file' => LEEDO_REQUIRE_DIRECTORY . 'inc/demo/demo-content.xml',
				'local_import_widget_file' => LEEDO_REQUIRE_DIRECTORY . 'inc/demo/widgets.wie',
				'local_import_customizer_file' => LEEDO_REQUIRE_DIRECTORY . 'inc/demo/customizer.dat'
			),
		);
	}
}
add_filter( 'pt-ocdi/import_files', 'leedo_demo_import_files' );

/**
 * Disable regenerate thumbnails
 */
add_filter( 'pt-ocdi/regenerate_thumbnails_in_content_import', '__return_false' );

/**
 * After setup function
 */
if ( ! function_exists( 'leedo_after_import_setup' ) ) {
	function leedo_after_import_setup() {

		global $wp_rewrite;

		// Set menus
		$primary_menu = get_term_by( 'name', 'Primary Menu', 'nav_menu' );
		$footer_menu = get_term_by( 'name', 'Footer Menu', 'nav_menu' );

		set_theme_mod( 'nav_menu_locations', array(
			'primary-menu' => $primary_menu->term_id,
			'footer-menu' => $footer_menu->term_id
		) );

		// Set pages
		$front_page = get_page_by_title( 'Homepage 01' );
		if ( isset( $front_page->ID ) ) {
			update_option( 'show_on_front', 'page' );
			update_option( 'page_on_front', $front_page->ID );
		}

		// Update option
		update_option( 'date_format', 'd F Y' );

		// Update permalink
		$wp_rewrite->set_permalink_structure( '/%postname%/' );

		// Update BSF Global Scripts
		if ( function_exists( 'bsf_update_option' ) ) {
			bsf_update_option( 'ultimate_global_scripts', 'enable' );
		}

		// Import Revolution Slider
		if ( class_exists( 'RevSlider' ) ) {
			$revo_slider = new RevSlider();

			$slider_aliases = $revo_slider->getAllSliderAliases();
			$slider_array = array(
				'landing',
				'homepage-01',
				'homepage-02',
				'homepage-03',
				'homepage-05',
				'homepage-07',
				'homepage-08',
				'homepage-09',
				'homepage-10',
				'homepage-18',
				'homepage-19',
				'homepage-20'
			);

			foreach ( $slider_array as $slider ) {
				if ( ! in_array( $slider, $slider_aliases ) ) {
					$path = LEEDO_REQUIRE_DIRECTORY . 'inc/demo/sliders/' . $slider . '.zip';
					if ( file_exists( $path ) ) {
						$revo_slider->importSliderFromPost( true, true, $path );
					}
				}
			}
		}

		// Set default vars for Elementor
		if ( ! get_option( 'elementor_container_width' ) ) {
			update_option( 'elementor_container_width', '1300' );
		}

		if ( ! get_option( 'elementor_space_between_widgets' ) ) {
			update_option( 'elementor_space_between_widgets', '0' );
		}

		if ( ! get_option( 'elementor_disable_color_schemes' ) ) {
			update_option( 'elementor_disable_color_schemes', 'yes' );
		}

		if ( ! get_option( 'elementor_disable_typography_schemes' ) ) {
			update_option( 'elementor_disable_typography_schemes', 'yes' );
		}

		$cpt_support = get_option( 'elementor_cpt_support' );

		// Check if option DOESN'T exist in db
		if ( ! $cpt_support ) {
			$cpt_support = [ 'page', 'post', 'portfolio', 'product' ]; // create array of our default supported post types
			update_option( 'elementor_cpt_support', $cpt_support ); // write it to the database
		}

		// If it DOES exist, but portfolio is NOT defined
		else if ( ! in_array( 'portfolio', $cpt_support ) ) {
			$cpt_support[] = 'portfolio'; // append to array
			update_option( 'elementor_cpt_support', $cpt_support ); // update database
		}

	}
}
add_action( 'pt-ocdi/after_import', 'leedo_after_import_setup' );

/**
 * WPBakery set as theme
 */
if ( ! function_exists( 'leedo_vc_set_as_theme' ) ) {
	function leedo_vc_set_as_theme() {

		if ( function_exists( 'vc_set_default_editor_post_types' ) ) {
			vc_set_default_editor_post_types( array(
				'page',
				'post',
				'portfolio',
				'product'
			) );
		}

	}
}
add_action( 'vc_before_init', 'leedo_vc_set_as_theme' );