<?php

/**
 * @author: VLThemes
 * @version: 2.0.0
 */

/**
 * Enqueue assets
 */
if ( ! class_exists( 'LeedoThemeEnqueueAssets' ) ) {
	class LeedoThemeEnqueueAssets {

		public function __construct() {
			$theme_info = wp_get_theme();
			$this->assets_dir = LEEDO_THEME_DIRECTORY . 'assets/';
			$this->customizer_frontend_css = LEEDO_THEME_DIRECTORY .'inc/framework/customizer-frontend.css';
			$this->customizer_editor_css = LEEDO_THEME_DIRECTORY .'inc/framework/customizer-editor.css';
			$this->theme_version = $theme_info[ 'Version' ];
			$this->init_assets();
		}

		public function fonts_url() {
			$fonts_url = '';
			$fonts = [];
			$display = 'swap';
			$fonts[] = 'Montserrat:wght@400;500;600;700;800';
			$fonts[] = 'Mulish:ital,wght@0,400;0,600;1,400';

			if ( $fonts ) {
				$fonts_url = add_query_arg( array(
					'family' => implode( '&family=', $fonts ),
					'display' => urlencode( $display )
				), 'https://fonts.googleapis.com/css2?family=' );
			}

			return $fonts_url;
		}

		public function init_assets() {
			add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_frontend_scripts' ) );
			add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_frontend_styles' ) );
			add_action( 'wp_default_scripts', array( $this, 'enqueue_default_scripts' ) );
			add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_admin_styles' ) );
			add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_admin_scripts' ) );
			add_action( 'enqueue_block_editor_assets', array( $this, 'enqueue_gutenberg_editor_styles' ) );
		}

		public function enqueue_default_scripts( $wp_scripts ) {

			if ( is_admin() ) {
				return;
			}

			if ( leedo_get_theme_mod( 'jquery_in_footer' ) == 'disable' ) {
				return;
			}

			$wp_scripts->add_data( 'jquery', 'group', 1 );
			$wp_scripts->add_data( 'jquery-core', 'group', 1 );
			$wp_scripts->add_data( 'jquery-migrate', 'group', 1 );

		}

		public function enqueue_frontend_scripts() {
			if ( is_singular() && comments_open() ) {
				wp_enqueue_script( 'comment-reply' );
			}

			// Enqueue default scripts
			wp_enqueue_script( 'imagesloaded' );
			wp_enqueue_script( 'jquery-masonry' );

			if ( leedo_get_theme_mod( 'google_map_api_key' ) ) {
				$api = 'https://maps.googleapis.com/maps/api/js';
				$map_key = leedo_get_theme_mod( 'google_map_api_key' );
				if ( false != $map_key ) {
					$arr_params = array(
						'key' => $map_key,
					);
					$api = esc_url( add_query_arg( $arr_params, $api ) );
				}
				wp_enqueue_script( 'gmap-api-key', $api, null, null, false );
			}

			// Enqueue theme scripts
			if ( leedo_get_theme_mod( 'nprogress' ) == 'enable' ) {
				wp_enqueue_script( 'nprogress', $this->assets_dir .'vendors/js/nprogress.js', [ 'jquery' ], $this->theme_version, true );
			}
			wp_enqueue_script( 'superfish', $this->assets_dir .'vendors/js/superfish.js', [ 'jquery' ], $this->theme_version, true );
			wp_enqueue_script( 'superclick', $this->assets_dir .'vendors/js/superclick.js', [ 'jquery' ], $this->theme_version, true );
			wp_enqueue_script( 'inview', $this->assets_dir .'vendors/js/jquery.inview.js', [ 'jquery' ], $this->theme_version, true );
			wp_enqueue_script( 'theia-sticky-sidebar', $this->assets_dir .'vendors/js/theia-sticky-sidebar.js', [ 'jquery' ], $this->theme_version, true );
			wp_enqueue_script( 'fancybox', $this->assets_dir .'vendors/js/jquery.fancybox.js', [ 'jquery' ], $this->theme_version, true );
			wp_enqueue_script( 'fitvids', $this->assets_dir .'vendors/js/fitvids.js', [ 'jquery' ], $this->theme_version, true );
			wp_enqueue_script( 'jarallax', $this->assets_dir .'vendors/js/jarallax.js', [ 'jquery' ], $this->theme_version, true );
			wp_enqueue_script( 'jarallax-element', $this->assets_dir .'vendors/js/jarallax-element.js', [ 'jquery' ], $this->theme_version, true );
			wp_enqueue_script( 'scrollTo', $this->assets_dir .'vendors/js/jquery.scrollTo.js', [ 'jquery' ], $this->theme_version, true );
			wp_enqueue_script( 'swiper-bundle', $this->assets_dir .'vendors/js/swiper-bundle.js', [ 'jquery' ], $this->theme_version, true );
			wp_enqueue_script( 'anime', $this->assets_dir .'vendors/js/anime.min.js', [ 'jquery' ], $this->theme_version, true );
			wp_enqueue_script( 'matchHeight', $this->assets_dir .'vendors/js/jquery.matchHeight.js', [ 'jquery' ], $this->theme_version, true );
			wp_enqueue_script( 'howler', $this->assets_dir .'vendors/js/howler.js', [ 'jquery' ], $this->theme_version, true );
			wp_enqueue_script( 'fittext', $this->assets_dir .'vendors/js/jquery.fittext.js', [ 'jquery' ], $this->theme_version, true );
			wp_enqueue_script( 'countdown', $this->assets_dir .'vendors/js/jquery.countdown.js', [ 'jquery' ], $this->theme_version, true );
			wp_enqueue_script( 'circle-progress', $this->assets_dir .'vendors/js/circle-progress.js', [ 'jquery' ], $this->theme_version, true );
			wp_enqueue_script( 'typed', $this->assets_dir .'vendors/js/typed.min.js', [ 'jquery' ], $this->theme_version, true );

			if ( leedo_get_theme_mod( 'animation_on_scroll' ) == 'enable' ) {
				wp_enqueue_script( 'aos', $this->assets_dir .'vendors/js/aos.js', [ 'jquery' ], $this->theme_version, true );
			}

			// Enqueue theme helper script
			wp_enqueue_script( 'vlt-helpers', $this->assets_dir .'scripts/helpers.js', [ 'jquery' ], $this->theme_version, true );

			// Enqueue controllers
			wp_enqueue_script( 'vlt-controllers', $this->assets_dir .'scripts/controllers.min.js', [ 'jquery' ], $this->theme_version, true );
			wp_localize_script(
				'vlt-controllers',
				'VLT_COUNTDOWN_CDATA',
				array(
					'days' => esc_html__( 'Days', 'leedo' ),
					'hours' => esc_html__( 'Hours', 'leedo' ),
					'minutes' => esc_html__( 'Minutes', 'leedo' ),
					'seconds' => esc_html__( 'Seconds', 'leedo' ),
				)
			);
			if ( leedo_get_theme_mod( 'menu_toggle_sound' ) == 'enable' ) {
				wp_localize_script(
					'vlt-controllers',
					'VLT_MENU_TOGGLE_SOUND_CDATA',
					array(
						'open' => leedo_get_theme_mod( 'open_click_sound' ),
						'close' => leedo_get_theme_mod( 'close_click_sound' ),
					)
				);
			}
		}

		public function enqueue_gutenberg_editor_styles() {
			wp_enqueue_style( 'vlt-gutenberg', $this->assets_dir .'css/gutenberg-style.min.css', [], $this->theme_version );
		}

		public function enqueue_admin_styles() {

			// Icons and fonts
			wp_enqueue_style( 'leedo', $this->assets_dir .'fonts/leedo/style.css', [], $this->theme_version );
			wp_enqueue_style( 'socicons', $this->assets_dir . 'fonts/socicons/socicon.css', [], $this->theme_version );

			wp_enqueue_style( 'vlt-admin-style', $this->assets_dir .'css/admin.css', [], $this->theme_version );
			if ( ! class_exists( 'Kirki' ) ) {
				wp_enqueue_style( 'vlt-google-fonts-editor', $this->fonts_url(), [], null );
				wp_enqueue_style( 'vlt-customizer-editor', $this->customizer_editor_css, [], $this->theme_version );
			}
		}

		public function enqueue_admin_scripts() {
			wp_enqueue_script( 'vlt-admin-script', $this->assets_dir .'scripts/admin.js', [ 'jquery' ], $this->theme_version, true );
		}

		public function enqueue_frontend_styles() {
			wp_enqueue_style( 'style', get_stylesheet_uri() );
			wp_enqueue_style( 'fancybox', $this->assets_dir . 'vendors/css/jquery.fancybox.css', [], $this->theme_version );
			wp_enqueue_style( 'swiper-bundle', $this->assets_dir . 'vendors/css/swiper-bundle.css', [], $this->theme_version );
			if ( leedo_get_theme_mod( 'animation_on_scroll' ) == 'enable' ) {
				wp_enqueue_style( 'aos', $this->assets_dir . 'vendors/css/aos.css', [], $this->theme_version );
			}

			// Icons and fonts
			wp_enqueue_style( 'leedo', $this->assets_dir .'fonts/leedo/style.css', [], $this->theme_version );
			wp_enqueue_style( 'socicons', $this->assets_dir . 'fonts/socicons/socicon.css', [], $this->theme_version );

			wp_enqueue_style( 'vlt-main-css', $this->assets_dir .'css/main.min.css', [], $this->theme_version );
			if ( ! class_exists( 'Kirki' ) ) {
				wp_enqueue_style( 'vlt-google-fonts-frontend', $this->fonts_url(), [], null );
				wp_enqueue_style( 'vlt-customizer-frontend', $this->customizer_frontend_css, [], $this->theme_version );
			}
		}

	}

	new LeedoThemeEnqueueAssets;

}