<?php

/**
 * @author: VLThemes
 * @version: 2.0.0
 */

/**
 * ACF in Admin Panel
 */
if ( ! function_exists( 'leedo_acf_in_admin_panel' ) ) {
	function leedo_acf_in_admin_panel() {
		return leedo_get_theme_mod( 'acf_show_admin_panel' ) == 'show' ? true : false;
	}
}
add_filter( 'leedo/acf_show_admin_panel', 'leedo_acf_in_admin_panel' );

/**
 * Add body class
 */
if ( ! function_exists( 'leedo_add_body_class' ) ) {
	function leedo_add_body_class( $classes ) {
		$classes[] = '';
		if ( ! wp_is_mobile() ) {
			$classes[] = 'no-mobile';
		} else {
			$classes[] = 'is-mobile';
		}
		return $classes;
	}
}
add_filter( 'body_class', 'leedo_add_body_class' );

/**
 * Add html class
 */
if ( ! function_exists( 'leedo_add_html_class' ) ) {
	function leedo_add_html_class( $classes = '' ) {
		// header
		$acf_header = leedo_get_theme_mod( 'page_custom_navigation', true );
		$classes .= ' vlt-is--header-' . leedo_get_theme_mod( 'navigation_type', $acf_header );

		// mobile sticky header
		if ( leedo_get_theme_mod( 'mobile_navigation_sticky' ) == 'enable' ) {
			$classes .= ' vlt-is--mobile-menu-fixed';
		}

		// footer
		$acf_footer = leedo_get_theme_mod( 'page_custom_footer', true );
		$classes .= ' vlt-is--footer-' . leedo_get_theme_mod( 'footer_layout', $acf_footer );
		if ( leedo_get_theme_mod( 'footer_fixed', $acf_footer ) == 'enable' ) {
			$classes .= ' vlt-is--footer-fixed';
		}

		// lowercase mode
		if ( leedo_get_theme_mod( 'lowercase_mode' ) == 'enable' ) {
			$classes .= ' vlt-is--lowercase-mode';
		}

		// site protection
		$acf_page_custom_site_protection = leedo_get_theme_mod( 'page_custom_site_protection', true );
		$classes .= ( leedo_get_theme_mod( 'site_protection', $acf_page_custom_site_protection ) == 'show' && ! current_user_can( 'administrator' ) ) ? ' vlt-is--site-protection' : '';

		// onepage navigation
		$classes .= leedo_get_theme_mod( 'onepage_navigation', true ) ? ' vlt-is--onepage-navigation' : '';

		return apply_filters( 'leedo/add_html_class', leedo_sanitize_class( $classes ) );
	}
}

/**
 * Get post password form
 */
if ( ! function_exists( 'leedo_get_post_password_form' ) ) {
	function leedo_get_post_password_form() {
		global $post;
		$label = 'pwbox-'.( empty( $post->ID ) ? rand() : $post->ID );
		$output = '<form class="vlt-post-password-form" action="' . esc_url( site_url( 'wp-login.php?action=postpass', 'login_post' ) ) . '" method="post">';
		$output .= '<i class="leedo-password"></i>';
		$output .= '<h5>' . esc_html__( 'Password Protected', 'leedo' ) . '</h5>';
		$output .= '<p>' . esc_html__( 'This content is restricted access, please type the password below and get access.', 'leedo' ) . '</p>';
		$output .= '<div class="vlt-form-group">';
		$output .= '<input name="post_password" id="' . $label . '" type="password" size="20" placeholder="' . esc_attr__( 'Password:' , 'leedo' ) . '" class="vlt-border-white">';
		$output .= '</div>';
		$output .= '<button class="vlt-btn vlt-btn--primary vlt-btn--effect block"><span>' . esc_attr__( 'Get Access' , 'leedo' ) . '</span></button>';
		$output .= '</form>';
		return apply_filters( 'leedo/get_post_password_form', $output );
	}
}
add_filter( 'the_password_form', 'leedo_get_post_password_form' );

/**
 * Admin logo link
 */
if ( ! function_exists( 'leedo_change_admin_logo_link' ) ) {
	function leedo_change_admin_logo_link() {
		return home_url( '/' );
	}
}
add_filter( 'login_headerurl', 'leedo_change_admin_logo_link' );

/**
 * Remove comment notes
 */
add_filter( 'comment_form_logged_in', '__return_empty_string' );

/**
 * Remove cf7 autop
 */
add_filter( 'wpcf7_autop_or_not', '__return_false' );

/**
 * Custom select for ACF
 */
if ( ! function_exists( 'leedo_add_custom_select_to_acf' ) ) {
	function leedo_add_custom_select_to_acf( $field, $type = null ) {

		// reset choices
		$field['choices'] = [];

		$args = [
			'post_type' => 'elementor_library',
			'posts_per_page' => -1,
		];

		if ( $type ) {

			$args[ 'tax_query' ] = [
				[
					'taxonomy' => 'elementor_library_type',
					'field' => 'slug',
					'terms' => $type,
				],
			];

		}

		$page_templates = get_posts( $args );

		$field['choices'][0] = esc_html__( 'Select a Template', 'leedo' );

		if ( ! empty( $page_templates ) && ! is_wp_error( $page_templates ) ) {
			foreach ( $page_templates as $post ) {
				$field['choices'][$post->ID] = $post->post_title;
			}
		} else {
			$field['choices'][0] = esc_html__( 'Create a Template First', 'leedo' );
		}

		// return the field
		return $field;

	}
}
add_filter( 'acf/load_field/name=footer_template', 'leedo_add_custom_select_to_acf' );

/**
 * Add comma to tag widget
 */
if ( ! function_exists( 'leedo_filter_tag_cloud' ) ) {
	function leedo_filter_tag_cloud( $args ) {
		$args['smallest'] = 18;
		$args['largest'] = 18;
		$args['unit'] = 'px';
		$args['orderby'] = 'count';
		$args['order'] = 'DESC';
		$args['separator']= ', ';
		return $args;
	}
}
add_filter ( 'widget_tag_cloud_args', 'leedo_filter_tag_cloud' );

/**
 * Extend mime tipes
 */
if ( ! function_exists( 'leedo_mime_types' ) ) {
	function leedo_mime_types( $mime_types ) {
		$mime_types['mp3'] = 'audio/mpeg';
		$mime_types['svg'] = 'image/svg+xml';
		return $mime_types;
	}
}
add_filter( 'upload_mimes', 'leedo_mime_types' );

/**
 * Disabling the scaling
 */
add_filter( 'big_image_size_threshold', '__return_false' );

/**
 * Override Elementor template
 */
add_filter( 'template_include', function( $template ) {
	if ( false !== strpos( $template, '/templates/canvas.php' ) ) {
		$template = LEEDO_REQUIRE_DIRECTORY . 'template-canvas-page.php';
	}
	return $template;
}, 12 );